@@ -353,7 +353,8 @@ class childgrowth(object):
                 print "NO AGE"
 
         if zscores is None:
-            return "NO SCORES????????????????"
+            print "NO SCORES????????????????"
+            return D('99.0')
 
 
         # fetch necessary scores from zscores dict and cast as decimals
